SidebarItem class
Model class representing a sidebar menu item
Constructors
-
SidebarItem({required IconData icon, required String label, List<
SidebarItem> ? subItems})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSubItems → bool
-
no setter
- icon → IconData
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subItems
→ List<
SidebarItem> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited